@@ -1,11 +1,10 @@
 from . import BaseCMLTest
 from click.testing import CliRunner
-import requests_mock
 
 
 class TestCMLLs(BaseCMLTest):
     def test_cml_ls_all(self):
-        with requests_mock.Mocker() as m:
+        with self.get_context() as m:
             self.setup_mocks(m)
             virl = self.get_virl()
             runner = CliRunner()
@@ -13,7 +12,7 @@ class TestCMLLs(BaseCMLTest):
             self.assertEqual(0, result.exit_code)
 
     def test_cml_ls(self):
-        with requests_mock.Mocker() as m:
+        with self.get_context() as m:
             self.setup_mocks(m)
             virl = self.get_virl()
             runner = CliRunner()
